Welcome to ClientVPS Mirrors

Help for package semdrw
Type: Package
Title: 'SEM Shiny'
Version: 0.1.0
Author: Kartikeya Bolar
Maintainer: Kartikeya Bolar <kartikeya.bolar@tapmi.edu.in>
Description: Interactive 'shiny' application for working with Structural Equation Modelling technique. Runtime examples are provided in the package function as well as at https://kartikeyab.shinyapps.io/semwebappk/ .
License: GPL-2
Encoding: UTF-8
LazyData: TRUE
Depends: R (≥ 3.0.3)
Imports: shiny,shinyAce,lavaan,semPlot,dplyr,semTools,psych
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2018-11-04 19:11:55 UTC; KARTIKEYA
Repository: CRAN
Date/Publication: 2018-11-14 11:00:02 UTC

Launch semdrw Interface

Description

semdrw() loads interactive user interface built using R shiny.

Usage

semdrw()

Details

Start semdrw

The interactive user interface is to provide an easy way for people who are learning sem and writing research paper. Includes example data for testing out a few example analysis.

Value

Nothing

Examples

## Not run: 
library(shiny)
semdrw()

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.